@@ -1,58 +1,60 @@
 #!/usr/bin/python3
 
-'''
+"""
 SPDX-License-Identifier: Apache-2.0
 Copyright 2017 Massachusetts Institute of Technology.
-'''
+"""
 
 import asyncio
-import http.server
-import multiprocessing
-import platform
-import datetime
-import signal
-from http.server import HTTPServer, BaseHTTPRequestHandler
-from socketserver import ThreadingMixIn
-import threading
 import base64
 import configparser
-import uuid
-import os
-import socket
-import sys
-import time
+import datetime
 import hashlib
-import zipfile
-import io
+import http.server
 import importlib
+import io
+import multiprocessing
+import os
+import platform
 import shutil
+import signal
+import socket
 import subprocess
-import psutil
+import sys
+import threading
+import time
+import uuid
+import zipfile
+from http.server import BaseHTTPRequestHandler, HTTPServer
+from socketserver import ThreadingMixIn
 
+import psutil
 from cryptography import x509
 from cryptography.hazmat.backends import default_backend
 from cryptography.hazmat.primitives import serialization
 
-from keylime import config
-from keylime import keylime_logging
-from keylime import cmd_exec
-from keylime import crypto
-from keylime import fs_util
-from keylime import json
-from keylime import revocation_notifier
-from keylime import registrar_client
-from keylime import secure_mount
-from keylime import user_utils
-from keylime import web_util
 from keylime import api_version as keylime_api_version
+from keylime import (
+    cmd_exec,
+    config,
+    crypto,
+    fs_util,
+    json,
+    keylime_logging,
+    registrar_client,
+    revocation_notifier,
+    secure_mount,
+    user_utils,
+    web_util,
+)
 from keylime.common import algorithms, validators
 from keylime.ima import ima
-from keylime.tpm.tpm_main import tpm
-from keylime.tpm.tpm_abstract import TPM_Utilities
 from keylime.tpm.tpm2_objects import pubkey_from_tpm2b_public
+from keylime.tpm.tpm_abstract import TPM_Utilities
+from keylime.tpm.tpm_main import tpm
 
 # Configure logger
-logger = keylime_logging.init_logging('cloudagent')
+logger = keylime_logging.init_logging("cloudagent")
 
 # lock required for multithreaded operation
 uvLock = threading.Lock()
@@ -62,7 +64,7 @@ tpm_instance = tpm(need_hw_tpm=True)
 
 
 class Handler(BaseHTTPRequestHandler):
-    parsed_path = ''
+    parsed_path = ""
 
     def do_HEAD(self):
         """Not supported"""
@@ -75,17 +77,14 @@ class Handler(BaseHTTPRequestHandler):
         The Cloud verifier requires an additional mask paramter.  If the uri or parameters are incorrect, a 400 response is returned.
         """
 
-        logger.info('GET invoked from %s with uri: %s', self.client_address, self.path)
+        logger.info("GET invoked from %s with uri: %s", self.client_address, self.path)
         rest_params = web_util.get_restful_params(self.path)
         if rest_params is None:
-            web_util.echo_json_response(
-                self, 405, "Not Implemented: Use /version, /keys/ or /quotes/ interfaces")
+            web_util.echo_json_response(self, 405, "Not Implemented: Use /version, /keys/ or /quotes/ interfaces")
             return
 
         if "version" in rest_params:
-            version_info = {
-                "supported_version": keylime_api_version.current_version()
-            }
+            version_info = {"supported_version": keylime_api_version.current_version()}
             web_util.echo_json_response(self, 200, "Success", version_info)
             return
 
@@ -93,87 +92,84 @@ class Handler(BaseHTTPRequestHandler):
             web_util.echo_json_response(self, 400, "API Version not supported")
             return
 
-        if "keys" in rest_params and rest_params['keys'] == 'verify':
+        if "keys" in rest_params and rest_params["keys"] == "verify":
             if self.server.K is None:
-                logger.info('GET key challenge returning 400 response. bootstrap key not available')
-                web_util.echo_json_response(
-                    self, 400, "Bootstrap key not yet available.")
+                logger.info("GET key challenge returning 400 response. bootstrap key not available")
+                web_util.echo_json_response(self, 400, "Bootstrap key not yet available.")
                 return
             if "challenge" not in rest_params:
-                logger.info('GET key challenge returning 400 response. No challenge provided')
-                web_util.echo_json_response(
-                    self, 400, "No challenge provided.")
+                logger.info("GET key challenge returning 400 response. No challenge provided")
+                web_util.echo_json_response(self, 400, "No challenge provided.")
                 return
 
-            challenge = rest_params['challenge']
+            challenge = rest_params["challenge"]
             response = {}
-            response['hmac'] = crypto.do_hmac(self.server.K, challenge)
+            response["hmac"] = crypto.do_hmac(self.server.K, challenge)
             web_util.echo_json_response(self, 200, "Success", response)
-            logger.info('GET key challenge returning 200 response.')
+            logger.info("GET key challenge returning 200 response.")
 
         # If agent pubkey requested
         elif "keys" in rest_params and rest_params["keys"] == "pubkey":
             response = {}
-            response['pubkey'] = self.server.rsapublickey_exportable
+            response["pubkey"] = self.server.rsapublickey_exportable
 
             web_util.echo_json_response(self, 200, "Success", response)
-            logger.info('GET pubkey returning 200 response.')
+            logger.info("GET pubkey returning 200 response.")
             return
 
         elif "quotes" in rest_params:
-            nonce = rest_params.get('nonce', None)
-            pcrmask = rest_params.get('mask', None)
-            ima_ml_entry = rest_params.get('ima_ml_entry', '0')
+            nonce = rest_params.get("nonce", None)
+            pcrmask = rest_params.get("mask", None)
+            ima_ml_entry = rest_params.get("ima_ml_entry", "0")
 
             # if the query is not messed up
             if nonce is None:
-                logger.warning('GET quote returning 400 response. nonce not provided as an HTTP parameter in request')
-                web_util.echo_json_response(
-                    self, 400, "nonce not provided as an HTTP parameter in request")
+                logger.warning("GET quote returning 400 response. nonce not provided as an HTTP parameter in request")
+                web_util.echo_json_response(self, 400, "nonce not provided as an HTTP parameter in request")
                 return
 
             # Sanitization assurance (for tpm.run() tasks below)
-            if not (nonce.isalnum() and
-                    (pcrmask is None or validators.valid_hex(pcrmask)) and
-                    ima_ml_entry.isalnum()):
-                logger.warning('GET quote returning 400 response. parameters should be strictly alphanumeric')
-                web_util.echo_json_response(
-                    self, 400, "parameters should be strictly alphanumeric")
+            if not (nonce.isalnum() and (pcrmask is None or validators.valid_hex(pcrmask)) and ima_ml_entry.isalnum()):
+                logger.warning("GET quote returning 400 response. parameters should be strictly alphanumeric")
+                web_util.echo_json_response(self, 400, "parameters should be strictly alphanumeric")
                 return
 
             if len(nonce) > tpm_instance.MAX_NONCE_SIZE:
-                logger.warning('GET quote returning 400 response. Nonce is too long (max size %i): %i',
-                               tpm_instance.MAX_NONCE_SIZE, len(nonce))
+                logger.warning(
+                    "GET quote returning 400 response. Nonce is too long (max size %i): %i",
+                    tpm_instance.MAX_NONCE_SIZE,
+                    len(nonce),
+                )
                 web_util.echo_json_response(
-                    self, 400, f'Nonce is too long (max size {tpm_instance.MAX_NONCE_SIZE}): {len(nonce)}')
+                    self, 400, f"Nonce is too long (max size {tpm_instance.MAX_NONCE_SIZE}): {len(nonce)}"
+                )
                 return
 
-            hash_alg = tpm_instance.defaults['hash']
-            quote = tpm_instance.create_quote(
-                nonce, self.server.rsapublickey_exportable, pcrmask, hash_alg)
+            hash_alg = tpm_instance.defaults["hash"]
+            quote = tpm_instance.create_quote(nonce, self.server.rsapublickey_exportable, pcrmask, hash_alg)
             imaMask = pcrmask
 
             # Allow for a partial quote response (without pubkey)
-            enc_alg = tpm_instance.defaults['encrypt']
-            sign_alg = tpm_instance.defaults['sign']
+            enc_alg = tpm_instance.defaults["encrypt"]
+            sign_alg = tpm_instance.defaults["sign"]
 
             if "partial" in rest_params and (rest_params["partial"] is None or rest_params["partial"] == "1"):
                 response = {
-                    'quote': quote,
-                    'hash_alg': hash_alg,
-                    'enc_alg': enc_alg,
-                    'sign_alg': sign_alg,
+                    "quote": quote,
+                    "hash_alg": hash_alg,
+                    "enc_alg": enc_alg,
+                    "sign_alg": sign_alg,
                 }
             else:
                 response = {
-                    'quote': quote,
-                    'hash_alg': hash_alg,
-                    'enc_alg': enc_alg,
-                    'sign_alg': sign_alg,
-                    'pubkey': self.server.rsapublickey_exportable,
+                    "quote": quote,
+                    "hash_alg": hash_alg,
+                    "enc_alg": enc_alg,
+                    "sign_alg": sign_alg,
+                    "pubkey": self.server.rsapublickey_exportable,
                 }
 
-            response['boottime'] = self.server.boottime
+            response["boottime"] = self.server.boottime
 
             # return a measurement list if available
             if TPM_Utilities.check_mask(imaMask, config.IMA_PCR):
@@ -182,8 +178,8 @@ class Handler(BaseHTTPRequestHandler):
                     ima_ml_entry = 0
                 ml, nth_entry, num_entries = ima.read_measurement_list(self.server.ima_log_file, ima_ml_entry)
                 if num_entries > 0:
-                    response['ima_measurement_list'] = ml
-                    response['ima_measurement_list_entry'] = nth_entry
+                    response["ima_measurement_list"] = ml
+                    response["ima_measurement_list_entry"] = nth_entry
                     self.server.next_ima_ml_entry = num_entries
 
             # similar to how IMA log retrievals are triggered by IMA_PCR, we trigger boot logs with MEASUREDBOOT_PCRs
@@ -194,14 +190,14 @@ class Handler(BaseHTTPRequestHandler):
                 if not self.server.tpm_log_file_data:
                     logger.warning("TPM2 event log not available: %s", config.MEASUREDBOOT_ML)
                 else:
-                    response['mb_measurement_list'] = self.server.tpm_log_file_data
+                    response["mb_measurement_list"] = self.server.tpm_log_file_data
 
             web_util.echo_json_response(self, 200, "Success", response)
-            logger.info('GET %s quote returning 200 response.', rest_params["quotes"])
+            logger.info("GET %s quote returning 200 response.", rest_params["quotes"])
             return
 
         else:
-            logger.warning('GET returning 400 response. uri not supported: %s', self.path)
+            logger.warning("GET returning 400 response. uri not supported: %s", self.path)
             web_util.echo_json_response(self, 400, "uri not supported")
             return
 
@@ -214,8 +210,7 @@ class Handler(BaseHTTPRequestHandler):
         rest_params = web_util.get_restful_params(self.path)
 
         if rest_params is None:
-            web_util.echo_json_response(
-                self, 405, "Not Implemented: Use /keys/ interface")
+            web_util.echo_json_response(self, 405, "Not Implemented: Use /keys/ interface")
             return
 
         if not rest_params["api_version"]:
@@ -226,42 +221,41 @@ class Handler(BaseHTTPRequestHandler):
             web_util.echo_json_response(self, 400, "Only /keys/ukey or /keys/vkey are supported")
             return
 
-        content_length = int(self.headers.get('Content-Length', 0))
+        content_length = int(self.headers.get("Content-Length", 0))
         if content_length <= 0:
-            logger.warning('POST returning 400 response, expected content in message. url: %s', self.path)
+            logger.warning("POST returning 400 response, expected content in message. url: %s", self.path)
             web_util.echo_json_response(self, 400, "expected content in message")
             return
 
         post_body = self.rfile.read(content_length)
         try:
             json_body = json.loads(post_body)
-            b64_encrypted_key = json_body['encrypted_key']
-            decrypted_key = crypto.rsa_decrypt(
-                self.server.rsaprivatekey, base64.b64decode(b64_encrypted_key))
+            b64_encrypted_key = json_body["encrypted_key"]
+            decrypted_key = crypto.rsa_decrypt(self.server.rsaprivatekey, base64.b64decode(b64_encrypted_key))
         except (ValueError, KeyError, TypeError) as e:
-            logger.warning('POST returning 400 response, could not parse body data: %s', e)
+            logger.warning("POST returning 400 response, could not parse body data: %s", e)
             web_util.echo_json_response(self, 400, "content is invalid")
             return
 
         have_derived_key = False
 
         if rest_params["keys"] == "ukey":
-            if 'auth_tag' not in json_body:
-                logger.warning('POST returning 400 response, U key provided without an auth_tag')
+            if "auth_tag" not in json_body:
+                logger.warning("POST returning 400 response, U key provided without an auth_tag")
                 web_util.echo_json_response(self, 400, "auth_tag is missing")
                 return
             self.server.add_U(decrypted_key)
-            self.server.auth_tag = json_body['auth_tag']
-            self.server.payload = json_body.get('payload', None)
+            self.server.auth_tag = json_body["auth_tag"]
+            self.server.payload = json_body.get("payload", None)
             have_derived_key = self.server.attempt_decryption()
         elif rest_params["keys"] == "vkey":
             self.server.add_V(decrypted_key)
             have_derived_key = self.server.attempt_decryption()
         else:
-            logger.warning('POST returning  response. uri not supported: %s', self.path)
+            logger.warning("POST returning  response. uri not supported: %s", self.path)
             web_util.echo_json_response(self, 400, "uri not supported")
             return
-        logger.info('POST of %s key returning 200', ('V', 'U')[rest_params["keys"] == "ukey"])
+        logger.info("POST of %s key returning 200", ("V", "U")[rest_params["keys"] == "ukey"])
         web_util.echo_json_response(self, 200, "Success")
 
         # no key yet, then we're done
@@ -277,7 +271,7 @@ class Handler(BaseHTTPRequestHandler):
             shutil.rmtree(os.path.join(secdir, "unzipped"))
 
         # write out key file
-        with open(os.path.join(secdir, self.server.enc_keyname), 'w', encoding="utf-8") as f:
+        with open(os.path.join(secdir, self.server.enc_keyname), "w", encoding="utf-8") as f:
             f.write(base64.b64encode(self.server.K).decode())
 
         # stow the U value for later
@@ -287,25 +281,26 @@ class Handler(BaseHTTPRequestHandler):
         tomeasure = self.server.K
 
         # if we have a good key, now attempt to write out the encrypted payload
-        dec_path = os.path.join(secdir,
-                                config.get('cloud_agent', "dec_payload_file"))
+        dec_path = os.path.join(secdir, config.get("cloud_agent", "dec_payload_file"))
         enc_path = os.path.join(config.WORK_DIR, "encrypted_payload")
 
         dec_payload = None
         enc_payload = None
         if self.server.payload is not None:
-            if (not self.server.mtls_cert_enabled and
-                not config.getboolean('cloud_agent', 'enable_insecure_payload', fallback=False)):
-                logger.warning('agent mTLS is disabled, and unless "enable_insecure_payload" is set to "True", payloads cannot be deployed')
+            if not self.server.mtls_cert_enabled and not config.getboolean(
+                "cloud_agent", "enable_insecure_payload", fallback=False
+            ):
+                logger.warning(
+                    'agent mTLS is disabled, and unless "enable_insecure_payload" is set to "True", payloads cannot be deployed'
+                )
                 enc_payload = None
             else:
-                dec_payload = crypto.decrypt(
-                    self.server.payload, bytes(self.server.K))
+                dec_payload = crypto.decrypt(self.server.payload, bytes(self.server.K))
                 enc_payload = self.server.payload
 
         elif os.path.exists(enc_path):
             # if no payload provided, try to decrypt one from a previous run stored in encrypted_payload
-            with open(enc_path, 'rb') as f:
+            with open(enc_path, "rb") as f:
                 enc_payload = f.read()
             try:
                 dec_payload = crypto.decrypt(enc_payload, self.server.K)
@@ -317,8 +312,8 @@ class Handler(BaseHTTPRequestHandler):
 
         # also write out encrypted payload to be decrytped next time
         if enc_payload is not None:
-            with open(enc_path, 'wb') as f:
-                f.write(self.server.payload.encode('utf-8'))
+            with open(enc_path, "wb") as f:
+                f.write(self.server.payload.encode("utf-8"))
 
         # deal with payload
         payload_thread = None
@@ -326,39 +321,44 @@ class Handler(BaseHTTPRequestHandler):
             tomeasure = tomeasure + dec_payload
             # see if payload is a zip
             zfio = io.BytesIO(dec_payload)
-            if config.getboolean('cloud_agent', 'extract_payload_zip') and zipfile.is_zipfile(zfio):
+            if config.getboolean("cloud_agent", "extract_payload_zip") and zipfile.is_zipfile(zfio):
                 logger.info("Decrypting and unzipping payload to %s/unzipped", secdir)
-                with zipfile.ZipFile(zfio, 'r')as f:
+                with zipfile.ZipFile(zfio, "r") as f:
                     f.extractall(os.path.join(secdir, "unzipped"))
 
                 # run an included script if one has been provided
-                initscript = config.get('cloud_agent', 'payload_script')
+                initscript = config.get("cloud_agent", "payload_script")
                 if initscript != "":
+
                     def initthread():
                         env = os.environ.copy()
-                        env['AGENT_UUID'] = self.server.agent_uuid
-                        with subprocess.Popen(["/bin/bash", initscript], env=env, shell=False,
-                                                cwd=os.path.join(secdir, "unzipped"),
-                                                stdout=subprocess.PIPE, stderr=subprocess.STDOUT) as proc:
-                            for line in iter(proc.stdout.readline, b''):
+                        env["AGENT_UUID"] = self.server.agent_uuid
+                        with subprocess.Popen(
+                            ["/bin/bash", initscript],
+                            env=env,
+                            shell=False,
+                            cwd=os.path.join(secdir, "unzipped"),
+                            stdout=subprocess.PIPE,
+                            stderr=subprocess.STDOUT,
+                        ) as proc:
+                            for line in iter(proc.stdout.readline, b""):
                                 logger.debug("init-output: %s", line.strip())
                             # should be a no-op as poll already told us it's done
                             proc.wait()
 
-                    if not os.path.exists(
-                            os.path.join(secdir, "unzipped", initscript)):
+                    if not os.path.exists(os.path.join(secdir, "unzipped", initscript)):
                         logger.info("No payload script %s found in %s/unzipped", initscript, secdir)
                     else:
                         logger.info("Executing payload script: %s/unzipped/%s", secdir, initscript)
                         payload_thread = threading.Thread(target=initthread, daemon=True)
             else:
                 logger.info("Decrypting payload to %s", dec_path)
-                with open(dec_path, 'wb') as f:
+                with open(dec_path, "wb") as f:
                     f.write(dec_payload)
             zfio.close()
 
         # now extend a measurement of the payload and key if there was one
-        pcr = config.getint('cloud_agent', 'measure_payload_pcr')
+        pcr = config.getint("cloud_agent", "measure_payload_pcr")
         if 0 < pcr < 24:
             logger.info("extending measurement of payload into PCR %s", pcr)
             measured = tpm_instance.hashdigest(tomeasure)
@@ -373,6 +373,7 @@ class Handler(BaseHTTPRequestHandler):
     def log_message(self, format, *args):
         return
 
+
 # consider using PooledProcessMixIn
 # https://github.com/muayyad-alsadi/python-PooledProcessMixIn
 
@@ -398,7 +399,7 @@ class CloudAgentHTTPServer(ThreadingMixIn, HTTPServer):
     K = None
     final_U = None
     agent_uuid = None
-    next_ima_ml_entry = 0 # The next IMA log offset the verifier may ask for.
+    next_ima_ml_entry = 0  # The next IMA log offset the verifier may ask for.
     boottime = int(psutil.boot_time())
 
     def __init__(self, server_address, RequestHandlerClass, agent_uuid, contact_ip, ima_log_file, tpm_log_file_data):
@@ -406,7 +407,7 @@ class CloudAgentHTTPServer(ThreadingMixIn, HTTPServer):
         # Find the locations for the U/V transport and mTLS key and certificate.
         # They are either relative to secdir (/var/lib/keylime/secure) or absolute paths.
         secdir = secure_mount.mount()
-        keyname = config.get('cloud_agent', 'rsa_keyname')
+        keyname = config.get("cloud_agent", "rsa_keyname")
         if not os.path.isabs(keyname):
             keyname = os.path.join(secdir, keyname)
 
@@ -424,12 +425,11 @@ class CloudAgentHTTPServer(ThreadingMixIn, HTTPServer):
 
         self.rsakey_path = keyname
         self.rsaprivatekey = rsa_key
-        self.rsapublickey_exportable = crypto.rsa_export_pubkey(
-            self.rsaprivatekey)
+        self.rsapublickey_exportable = crypto.rsa_export_pubkey(self.rsaprivatekey)
 
-        self.mtls_cert_enabled = config.getboolean('cloud_agent', 'mtls_cert_enabled', fallback=False)
+        self.mtls_cert_enabled = config.getboolean("cloud_agent", "mtls_cert_enabled", fallback=False)
         if self.mtls_cert_enabled:
-            certname = config.get('cloud_agent', 'mtls_cert')
+            certname = config.get("cloud_agent", "mtls_cert")
 
             if not os.path.isabs(certname):
                 certname = os.path.join(secdir, certname)
@@ -461,9 +461,8 @@ class CloudAgentHTTPServer(ThreadingMixIn, HTTPServer):
         if nvram_u is not None:
             logger.info("Existing U loaded from TPM NVRAM")
             self.add_U(nvram_u)
-        http.server.HTTPServer.__init__(
-            self, server_address, RequestHandlerClass)
-        self.enc_keyname = config.get('cloud_agent', 'enc_keyname')
+        http.server.HTTPServer.__init__(self, server_address, RequestHandlerClass)
+        self.enc_keyname = config.get("cloud_agent", "enc_keyname")
         self.agent_uuid = agent_uuid
         self.ima_log_file = ima_log_file
         self.tpm_log_file_data = tpm_log_file_data
@@ -555,35 +554,33 @@ def revocation_listener():
     This configures and starts the revocation listener. It is designed to be started in a separate process.
     """
 
-    if config.has_option('cloud_agent', 'listen_notifications'):
-        if not config.getboolean('cloud_agent', 'listen_notifications'):
+    if config.has_option("cloud_agent", "listen_notifications"):
+        if not config.getboolean("cloud_agent", "listen_notifications"):
             return
 
     # keep old typo "listen_notfications" around for a few versions
-    if config.has_option('cloud_agent', 'listen_notfications'):
+    if config.has_option("cloud_agent", "listen_notfications"):
         logger.warning('Option typo "listen_notfications" is deprecated. Please use "listen_notifications" instead.')
-        if not config.getboolean('cloud_agent', 'listen_notfications'):
+        if not config.getboolean("cloud_agent", "listen_notfications"):
             return
 
     secdir = secure_mount.mount()
 
-    cert_path = config.get('cloud_agent', 'revocation_cert')
+    cert_path = config.get("cloud_agent", "revocation_cert")
     if cert_path == "default":
-        cert_path = os.path.join(secdir,
-                                 "unzipped/RevocationNotifier-cert.crt")
-    elif cert_path[0] != '/':
+        cert_path = os.path.join(secdir, "unzipped/RevocationNotifier-cert.crt")
+    elif cert_path[0] != "/":
         # if it is a relative, convert to absolute in work_dir
-        cert_path = os.path.abspath(
-            os.path.join(config.WORK_DIR, cert_path))
+        cert_path = os.path.abspath(os.path.join(config.WORK_DIR, cert_path))
 
     # Callback function handling the revocations
     def perform_actions(revocation):
         actionlist = []
 
         # load the actions from inside the keylime module
-        actionlisttxt = config.get('cloud_agent', 'revocation_actions')
+        actionlisttxt = config.get("cloud_agent", "revocation_actions")
         if actionlisttxt.strip() != "":
-            actionlist = actionlisttxt.split(',')
+            actionlist = actionlisttxt.split(",")
             actionlist = [f"revocation_actions.{i}" % i for i in actionlist]
 
         # load actions from unzipped
@@ -592,9 +589,9 @@ def revocation_listener():
             with open(action_list_path, encoding="utf-8") as f:
                 actionlisttxt = f.read()
             if actionlisttxt.strip() != "":
-                localactions = actionlisttxt.strip().split(',')
+                localactions = actionlisttxt.strip().split(",")
                 for action in localactions:
-                    if not action.startswith('local_action_'):
+                    if not action.startswith("local_action_"):
                         logger.warning("Invalid local action: %s. Must start with local_action_", action)
                     else:
                         actionlist.append(action)
@@ -607,7 +604,7 @@ def revocation_listener():
             logger.info("Executing revocation action %s", action)
             try:
                 module = importlib.import_module(action)
-                execute = getattr(module, 'execute')
+                execute = getattr(module, "execute")
                 asyncio.get_event_loop().run_until_complete(execute(revocation))
             except Exception as e:
                 logger.warning("Exception during execution of revocation action %s: %s", action, e)
@@ -615,8 +612,7 @@ def revocation_listener():
     try:
         while True:
             try:
-                revocation_notifier.await_notifications(
-                    perform_actions, revocation_cert_path=cert_path)
+                revocation_notifier.await_notifications(perform_actions, revocation_cert_path=cert_path)
             except Exception as e:
                 logger.exception(e)
                 logger.warning("No connection to revocation server, retrying in 10s...")
@@ -628,26 +624,27 @@ def revocation_listener():
 def main():
     for ML in [config.MEASUREDBOOT_ML, config.IMA_ML]:
         if not os.access(ML, os.F_OK):
-            logger.warning("Measurement list path %s not accessible by agent. Any attempt to instruct it to access this path - via \"keylime_tenant\" CLI - will result in agent process dying", ML)
+            logger.warning(
+                'Measurement list path %s not accessible by agent. Any attempt to instruct it to access this path - via "keylime_tenant" CLI - will result in agent process dying',
+                ML,
+            )
 
     ima_log_file = None
     if os.path.exists(config.IMA_ML):
-        ima_log_file = open(config.IMA_ML, 'r', encoding="utf-8")  #pylint: disable=consider-using-with
+        ima_log_file = open(config.IMA_ML, "r", encoding="utf-8")  # pylint: disable=consider-using-with
 
     tpm_log_file_data = None
     if os.path.exists(config.MEASUREDBOOT_ML):
-        with open(config.MEASUREDBOOT_ML, 'rb') as tpm_log_file:
+        with open(config.MEASUREDBOOT_ML, "rb") as tpm_log_file:
             tpm_log_file_data = base64.b64encode(tpm_log_file.read())
 
-    if config.get('cloud_agent', 'agent_uuid') == 'dmidecode':
+    if config.get("cloud_agent", "agent_uuid") == "dmidecode":
         if os.getuid() != 0:
-            raise RuntimeError('agent_uuid is configured to use dmidecode, '
-                               'but current process is not running as root.')
-        cmd = ['which', 'dmidecode']
+            raise RuntimeError("agent_uuid is configured to use dmidecode, but current process is not running as root.")
+        cmd = ["which", "dmidecode"]
         ret = cmd_exec.run(cmd, raiseOnError=False)
-        if ret['code'] != 0:
-            raise RuntimeError('agent_uuid is configured to use dmidecode, '
-                               'but it\'s is not found on the system.')
+        if ret["code"] != 0:
+            raise RuntimeError("agent_uuid is configured to use dmidecode, but it's is not found on the system.")
 
     # initialize the tmpfs partition to store keys if it isn't already available
     secdir = secure_mount.mount()
@@ -655,8 +652,8 @@ def main():
     # Now that operations requiring root privileges are done, drop privileges
     # if 'run_as' is available in the configuration.
     if os.getuid() == 0:
-        run_as = config.get('cloud_agent', 'run_as', fallback='')
-        if run_as != '':
+        run_as = config.get("cloud_agent", "run_as", fallback="")
+        if run_as != "":
             user_utils.chown(secdir, run_as)
             user_utils.change_uidgid(run_as)
             logger.info("Dropped privileges to %s", run_as)
@@ -667,16 +664,16 @@ def main():
 
     instance_tpm = tpm()
     # get params for initialization
-    registrar_ip = config.get('cloud_agent', 'registrar_ip')
-    registrar_port = config.get('cloud_agent', 'registrar_port')
+    registrar_ip = config.get("cloud_agent", "registrar_ip")
+    registrar_port = config.get("cloud_agent", "registrar_port")
 
     # get params for the verifier to contact the agent
     contact_ip = os.getenv("KEYLIME_AGENT_CONTACT_IP", None)
-    if contact_ip is None and config.has_option('cloud_agent', 'agent_contact_ip'):
-        contact_ip = config.get('cloud_agent', 'agent_contact_ip')
+    if contact_ip is None and config.has_option("cloud_agent", "agent_contact_ip"):
+        contact_ip = config.get("cloud_agent", "agent_contact_ip")
     contact_port = os.getenv("KEYLIME_AGENT_CONTACT_PORT", None)
-    if contact_port is None and config.has_option('cloud_agent', 'agent_contact_port'):
-        contact_port = config.get('cloud_agent', 'agent_contact_port', fallback="invalid")
+    if contact_port is None and config.has_option("cloud_agent", "agent_contact_port"):
+        contact_port = config.get("cloud_agent", "agent_contact_port", fallback="invalid")
 
     # change dir to working dir
     fs_util.ch_dir(config.WORK_DIR)
@@ -685,44 +682,51 @@ def main():
     os.umask(0o077)
 
     # initialize tpm
-    (ekcert, ek_tpm, aik_tpm) = instance_tpm.tpm_init(self_activate=False, config_pw=config.get(
-        'cloud_agent', 'tpm_ownerpassword'))  # this tells initialize not to self activate the AIK
+    (ekcert, ek_tpm, aik_tpm) = instance_tpm.tpm_init(
+        self_activate=False, config_pw=config.get("cloud_agent", "tpm_ownerpassword")
+    )  # this tells initialize not to self activate the AIK
 
     # Warn if kernel version is <5.10 and another algorithm than SHA1 is used,
     # because otherwise IMA will not work
     kernel_version = tuple(platform.release().split("-")[0].split("."))
-    if tuple(map(int,kernel_version)) < (5, 10, 0) and instance_tpm.defaults["hash"] != algorithms.Hash.SHA1:
-        logger.warning("IMA attestation only works on kernel versions <5.10 with SHA1 as hash algorithm. "
-                       "Even if ascii_runtime_measurements shows \"%s\" as the "
-                       "algorithm, it might be just padding zeros", (instance_tpm.defaults["hash"]))
+    if tuple(map(int, kernel_version)) < (5, 10, 0) and instance_tpm.defaults["hash"] != algorithms.Hash.SHA1:
+        logger.warning(
+            "IMA attestation only works on kernel versions <5.10 with SHA1 as hash algorithm. "
+            'Even if ascii_runtime_measurements shows "%s" as the '
+            "algorithm, it might be just padding zeros",
+            (instance_tpm.defaults["hash"]),
+        )
 
     if ekcert is None and instance_tpm.is_emulator():
-        ekcert = 'emulator'
+        ekcert = "emulator"
 
     # now we need the UUID
     try:
-        agent_uuid = config.get('cloud_agent', 'agent_uuid')
+        agent_uuid = config.get("cloud_agent", "agent_uuid")
     except configparser.NoOptionError:
         agent_uuid = None
-    if agent_uuid == 'hash_ek':
+    if agent_uuid == "hash_ek":
         ek_pubkey = pubkey_from_tpm2b_public(base64.b64decode(ek_tpm))
-        ek_pubkey_pem = ek_pubkey.public_bytes(encoding=serialization.Encoding.PEM,
-                                               format=serialization.PublicFormat.SubjectPublicKeyInfo)
+        ek_pubkey_pem = ek_pubkey.public_bytes(
+            encoding=serialization.Encoding.PEM, format=serialization.PublicFormat.SubjectPublicKeyInfo
+        )
         agent_uuid = hashlib.sha256(ek_pubkey_pem).hexdigest()
-    elif agent_uuid == 'generate' or agent_uuid is None:
+    elif agent_uuid == "generate" or agent_uuid is None:
         agent_uuid = str(uuid.uuid4())
-    elif agent_uuid == 'dmidecode':
-        cmd = ['dmidecode', '-s', 'system-uuid']
+    elif agent_uuid == "dmidecode":
+        cmd = ["dmidecode", "-s", "system-uuid"]
         ret = cmd_exec.run(cmd)
-        sys_uuid = ret['retout'][0].decode('utf-8')
+        sys_uuid = ret["retout"][0].decode("utf-8")
         agent_uuid = sys_uuid.strip()
         try:
             uuid.UUID(agent_uuid)
         except ValueError as e:
-            raise RuntimeError(f"The UUID returned from dmidecode is invalid: {str(e)}")  # pylint: disable=raise-missing-from
-    elif agent_uuid == 'hostname':
+            raise RuntimeError(  # pylint: disable=raise-missing-from
+                f"The UUID returned from dmidecode is invalid: {str(e)}"
+            )
+    elif agent_uuid == "hostname":
         agent_uuid = socket.getfqdn()
-    elif agent_uuid == 'environment':
+    elif agent_uuid == "environment":
         agent_uuid = os.getenv("KEYLIME_AGENT_UUID", None)
         if agent_uuid is None:
             raise RuntimeError("Env variable KEYLIME_AGENT_UUID is empty, but agent_uuid is set to 'environment'")
@@ -734,21 +738,25 @@ def main():
 
     logger.info("Agent UUID: %s", agent_uuid)
 
-    serveraddr = (config.get('cloud_agent', 'cloudagent_ip'),
-                  config.getint('cloud_agent', 'cloudagent_port'))
+    serveraddr = (config.get("cloud_agent", "cloudagent_ip"), config.getint("cloud_agent", "cloudagent_port"))
 
-    keylime_ca = config.get('cloud_agent', 'keylime_ca')
+    keylime_ca = config.get("cloud_agent", "keylime_ca")
     if keylime_ca == "default":
-        keylime_ca = os.path.join(config.WORK_DIR, 'cv_ca', 'cacert.crt')
+        keylime_ca = os.path.join(config.WORK_DIR, "cv_ca", "cacert.crt")
 
     server = CloudAgentHTTPServer(serveraddr, Handler, agent_uuid, contact_ip, ima_log_file, tpm_log_file_data)
     if server.mtls_cert_enabled:
         context = web_util.generate_mtls_context(server.mtls_cert_path, server.rsakey_path, keylime_ca, logger=logger)
         server.socket = context.wrap_socket(server.socket, server_side=True)
     else:
-        if not config.getboolean('cloud_agent', 'enable_insecure_payload', fallback=False) and config.get('cloud_agent', 'payload_script') != "":
-            raise RuntimeError('agent mTLS is disabled, while a tenant can instruct the agent to execute code on the node. '
-                               'In order to allow the running of the agent, "enable_insecure_payload" has to be set to "True"')
+        if (
+            not config.getboolean("cloud_agent", "enable_insecure_payload", fallback=False)
+            and config.get("cloud_agent", "payload_script") != ""
+        ):
+            raise RuntimeError(
+                "agent mTLS is disabled, while a tenant can instruct the agent to execute code on the node. "
+                'In order to allow the running of the agent, "enable_insecure_payload" has to be set to "True"'
+            )
 
     serverthread = threading.Thread(target=server.serve_forever, daemon=True)
 
@@ -758,7 +766,8 @@ def main():
         mtls_cert = server.mtls_cert.public_bytes(serialization.Encoding.PEM)
 
     keyblob = registrar_client.doRegisterAgent(
-        registrar_ip, registrar_port, agent_uuid, ek_tpm, ekcert, aik_tpm, mtls_cert, contact_ip, contact_port)
+        registrar_ip, registrar_port, agent_uuid, ek_tpm, ekcert, aik_tpm, mtls_cert, contact_ip, contact_port
+    )
 
     if keyblob is None:
         instance_tpm.flush_keys()
@@ -772,8 +781,7 @@ def main():
         raise Exception("Activation failed")
 
     # tell the registrar server we know the key
-    retval = registrar_client.doActivateAgent(
-        registrar_ip, registrar_port, agent_uuid, key)
+    retval = registrar_client.doActivateAgent(registrar_ip, registrar_port, agent_uuid, key)
 
     if not retval:
         instance_tpm.flush_keys()
@@ -783,7 +791,12 @@ def main():
     revocation_process = multiprocessing.Process(target=revocation_listener, daemon=True)
     revocation_process.start()
 
-    logger.info("Starting Cloud Agent on %s:%s with API version %s. Use <Ctrl-C> to stop", serveraddr[0], serveraddr[1], keylime_api_version.current_version())
+    logger.info(
+        "Starting Cloud Agent on %s:%s with API version %s. Use <Ctrl-C> to stop",
+        serveraddr[0],
+        serveraddr[1],
+        keylime_api_version.current_version(),
+    )
     serverthread.start()
 
     def shutdown_handler(*_):
