@@ -1,35 +1,34 @@
-'''
+"""
 SPDX-License-Identifier: Apache-2.0
 Copyright 2017 Massachusetts Institute of Technology.
-'''
-import signal
-from multiprocessing import Process
-import threading
+"""
 import functools
-import time
 import os
+import signal
 import sys
-
+import threading
+import time
+from multiprocessing import Process
 from typing import Optional
 
 import requests
-import zmq
 
-from keylime import config
-from keylime import crypto
-from keylime import json
-from keylime import keylime_logging
-from keylime import secure_mount
+from keylime import config, crypto, json, keylime_logging, secure_mount
 from keylime.common import retry
 
-
-logger = keylime_logging.init_logging('revocation_notifier')
+logger = keylime_logging.init_logging("revocation_notifier")
 broker_proc: Optional[Process] = None
 
 _SOCKET_PATH = "/var/run/keylime/keylime.verifier.ipc"
 
 
 def start_broker():
+    assert config.getboolean("cloud_verifier", "revocation_notifier")
+    try:
+        import zmq  # pylint: disable=import-outside-toplevel
+    except ImportError as error:
+        raise Exception("install PyZMQ for 'revocation_notifier' option") from error
+
     def worker():
         # do not receive signals form the parent process
         os.setpgrp()
@@ -47,7 +46,7 @@ def start_broker():
         frontend = context.socket(zmq.SUB)
         frontend.bind(f"ipc://{_SOCKET_PATH}")
 
-        frontend.setsockopt(zmq.SUBSCRIBE, b'')
+        frontend.setsockopt(zmq.SUBSCRIBE, b"")
 
         # Socket facing services
         backend = context.socket(zmq.PUB)
@@ -79,6 +78,12 @@ def stop_broker():
 
 
 def notify(tosend):
+    assert config.getboolean("cloud_verifier", "revocation_notifier")
+    try:
+        import zmq  # pylint: disable=import-outside-toplevel
+    except ImportError as error:
+        raise Exception("install PyZMQ for 'revocation_notifier' option") from error
+
     # python-requests internally uses either simplejson (preferred) or
     # the built-in json module, and when it is using the built-in one,
     # it may encounter difficulties handling bytes instead of strings.
@@ -93,16 +98,17 @@ def notify(tosend):
         time.sleep(0.2)
         # now send it out via 0mq
         logger.info("Sending revocation event to listening nodes...")
-        for i in range(config.getint('cloud_verifier', 'max_retries')):
+        for i in range(config.getint("cloud_verifier", "max_retries")):
             try:
                 mysock.send_string(json.dumps(tosend))
                 break
             except Exception as e:
-                interval = config.getfloat('cloud_verifier', 'retry_interval')
-                exponential_backoff = config.getboolean('cloud_verifier', 'exponential_backoff')
+                interval = config.getfloat("cloud_verifier", "retry_interval")
+                exponential_backoff = config.getboolean("cloud_verifier", "exponential_backoff")
                 next_retry = retry.retry_time(exponential_backoff, interval, i, logger)
-                logger.debug("Unable to publish revocation message %d times, trying again in %f seconds: %s",
-                             i, next_retry, e)
+                logger.debug(
+                    "Unable to publish revocation message %d times, trying again in %f seconds: %s", i, next_retry, e
+                )
                 time.sleep(next_retry)
         mysock.close()
 
@@ -112,9 +118,9 @@ def notify(tosend):
 
 
 def notify_webhook(tosend):
-    url = config.get('cloud_verifier', 'webhook_url', fallback='')
+    url = config.get("cloud_verifier", "webhook_url", fallback="")
     # Check if a url was specified
-    if url == '':
+    if url == "":
         return
 
     # Similarly to notify(), let's convert `tosend' to str to prevent
@@ -122,25 +128,32 @@ def notify_webhook(tosend):
     tosend = json.bytes_to_str(tosend)
 
     def worker_webhook(tosend, url):
-        interval = config.getfloat('cloud_verifier', 'retry_interval')
-        exponential_backoff = config.getboolean('cloud_verifier', 'exponential_backoff')
+        interval = config.getfloat("cloud_verifier", "retry_interval")
+        exponential_backoff = config.getboolean("cloud_verifier", "exponential_backoff")
         session = requests.session()
         logger.info("Sending revocation event via webhook...")
-        for i in range(config.getint('cloud_verifier', 'max_retries')):
+        for i in range(config.getint("cloud_verifier", "max_retries")):
             next_retry = retry.retry_time(exponential_backoff, interval, i, logger)
             try:
                 response = session.post(url, json=tosend, timeout=5)
                 if response.status_code in [200, 202]:
                     break
 
-                logger.debug("Unable to publish revocation message %d times via webhook, "
-                             "trying again in %d seconds. "
-                             "Server returned status code: %s",
-                             i, next_retry, response.status_code)
+                logger.debug(
+                    "Unable to publish revocation message %d times via webhook, "
+                    "trying again in %d seconds. "
+                    "Server returned status code: %s",
+                    i,
+                    next_retry,
+                    response.status_code,
+                )
             except requests.exceptions.RequestException as e:
-                logger.debug("Unable to publish revocation message %d times via webhook, "
-                             "trying again in %d seconds: %s",
-                             i, next_retry, e)
+                logger.debug(
+                    "Unable to publish revocation message %d times via webhook, trying again in %d seconds: %s",
+                    i,
+                    next_retry,
+                    e,
+                )
 
             time.sleep(next_retry)
 
@@ -153,6 +166,15 @@ cert_key = None
 
 
 def await_notifications(callback, revocation_cert_path):
+    # keep old typo "listen_notfications" around for a few versions
+    assert config.getboolean("cloud_agent", "listen_notifications", fallback=False) or config.getboolean(
+        "cloud_agent", "listen_notfications", fallback=False
+    )
+    try:
+        import zmq  # pylint: disable=import-outside-toplevel
+    except ImportError as error:
+        raise Exception("install PyZMQ for 'listen_notifications' option") from error
+
     global cert_key
 
     if revocation_cert_path is None:
@@ -160,15 +182,17 @@ def await_notifications(callback, revocation_cert_path):
 
     context = zmq.Context()
     mysock = context.socket(zmq.SUB)
-    mysock.setsockopt(zmq.SUBSCRIBE, b'')
+    mysock.setsockopt(zmq.SUBSCRIBE, b"")
     mysock.connect(
         f"tcp://{config.get('general', 'receive_revocation_ip')}:"
         f"{config.getint('general', 'receive_revocation_port')}"
     )
 
-    logger.info('Waiting for revocation messages on 0mq %s:%s',
-                config.get('general', 'receive_revocation_ip'),
-                config.getint('general', 'receive_revocation_port'))
+    logger.info(
+        "Waiting for revocation messages on 0mq %s:%s",
+        config.get("general", "receive_revocation_ip"),
+        config.getint("general", "receive_revocation_port"),
+    )
 
     while True:
         rawbody = mysock.recv()
@@ -177,23 +201,20 @@ def await_notifications(callback, revocation_cert_path):
         if cert_key is None:
             # load up the CV signing public key
             if revocation_cert_path is not None and os.path.exists(revocation_cert_path):
-                logger.info(
-                    "Lazy loading the revocation certificate from %s", revocation_cert_path)
+                logger.info("Lazy loading the revocation certificate from %s", revocation_cert_path)
                 with open(revocation_cert_path, "rb") as f:
                     certpem = f.read()
                 cert_key = crypto.x509_import_pubkey(certpem)
 
         if cert_key is None:
-            logger.warning("Unable to check signature of revocation message: %s not available",
-                           revocation_cert_path)
-        elif 'signature' not in body or body['signature'] == 'none':
+            logger.warning("Unable to check signature of revocation message: %s not available", revocation_cert_path)
+        elif "signature" not in body or body["signature"] == "none":
             logger.warning("No signature on revocation message from server")
-        elif not crypto.rsa_verify(cert_key, body['msg'].encode('utf-8'), body['signature'].encode('utf-8')):
+        elif not crypto.rsa_verify(cert_key, body["msg"].encode("utf-8"), body["signature"].encode("utf-8")):
             logger.error("Invalid revocation message siganture %s", body)
         else:
-            message = json.loads(body['msg'])
-            logger.debug(
-                "Revocation signature validated for revocation: %s", message)
+            message = json.loads(body["msg"])
+            logger.debug("Revocation signature validated for revocation: %s", message)
             callback(message)
 
 
@@ -212,16 +233,16 @@ def main():
     # time.sleep(0.5)
 
     json_body2 = {
-        'v': 'vbaby',
-        'agent_id': '2094aqrea3',
-        'cloudagent_ip': 'ipaddy',
-        'cloudagent_port': '39843',
-        'tpm_policy': '{"ab":"1"}',
-        'metadata': '{"cert_serial":"1"}',
-        'allowlist': '{}',
-        'ima_sign_verification_keys': '{}',
-        'revocation_key': '',
-        'revocation': '{"cert_serial":"1"}',
+        "v": "vbaby",
+        "agent_id": "2094aqrea3",
+        "cloudagent_ip": "ipaddy",
+        "cloudagent_port": "39843",
+        "tpm_policy": '{"ab":"1"}',
+        "metadata": '{"cert_serial":"1"}',
+        "allowlist": "{}",
+        "ima_sign_verification_keys": "{}",
+        "revocation_key": "",
+        "revocation": '{"cert_serial":"1"}',
     }
 
     print("sending notification")
